@@ -1,27 +1,70 @@
 package TRD::Velocity;
 
-#use warnings;
+use warnings;
 use strict;
-use Carp;
 
-use version;
-our $VERSION = qv('0.0.4');
+=head1 NAME
+
+TRD::Velocity - Template engine
+
+=head1 VERSION
+
+Version 0.0.5
+
+=cut
+
+our $VERSION = '0.0.5';
 our $debug = 0;
 
+=head1 SYNOPSIS
+
+    use TRD::Velocity;
+
+    $velo = new TRD::Velocity;
+    $velo->setTemplateFile( 'foo.html' );
+    $velo->set( 'name', 'value' );
+    $html_stmt = $velo->marge();
+    $ct = length( $html_stmt );
+    print "Content-Type: text/html\n";
+    print "Content-Length: ${ct}\n";
+    print "\n";
+    print $html_stmt;
+
+=head1 EXPORT
+
+A list of functions that can be exported.  You can delete this section
+if you don't export anything, such as for a purely object-oriented module.
+
+=head1 FUNCTIONS
+
+=head2 new
+
+    new Constructor.
+
+    my $velo = new TRD::Velocity;
+
+=cut
 #======================================================================
 sub new {
 	my $pkg = shift;
 	bless {
 		params => undef,
 		templateFile => undef,
-		templateData => undef,
-		contents => undef,
-		command => undef,
-		elsecommand => undef,
+		templateData => '',
+		contents => '',
+		command => '',
+		elsecommand => '',
 		options => undef,
 	}, $pkg;
 };
 
+=head2 set( <name>, <value> )
+
+    set parameter.
+
+    $velo->set( 'itemname', 'Apple' );
+
+=cut
 #======================================================================
 sub set {
 	my $self = shift;
@@ -31,6 +74,13 @@ sub set {
 	$self->{params}->{$name} = $value;
 }
 
+=head2 setTemplateFile( <TemplateFileName> )
+
+    set Template file.
+
+    $velo->setTemplateFile( './template/soldmail.txt' );
+
+=cut
 #======================================================================
 sub setTemplateFile {
 	my $self = shift;
@@ -48,6 +98,16 @@ sub setTemplateFile {
 	$self->{templateData} = $fdata;
 }
 
+=head2 setTemplateData( <TemplateData> )
+
+    set Template data.
+
+    my $template =<<EOT;
+    Sender: ${sender}
+    Email: ${email}
+    EOT
+    $velo->setTemplateData( $template );
+=cut
 #======================================================================
 sub setTemplateData {
 	my $self = shift;
@@ -58,6 +118,13 @@ sub setTemplateData {
 	$self->{templateData} = $templateData;
 }
 
+=head2 marge
+
+    Marge template to parameters.
+
+    my $doc = $velo->marge();
+
+=cut
 #======================================================================
 sub marge {
 	my $self = shift;
@@ -77,27 +144,51 @@ sub marge {
 	$contents;
 }
 
+=head2 tag_handler
+
+    private function.
+
+=cut
 #======================================================================
 sub tag_handler {
 	my $self = shift;
 	$self->{contents} = shift;
 	my( $htm, $tag, $contents );
+	my @s;
 
-	$htm = '';
-	$tag = '';
+	$contents = '';
 	while( $self->{contents} ne '' ){
-		( $htm, $tag, $self->{contents} ) = split( /(#if|#foreach)/is, $self->{contents}, 2 );
-		if( $tag eq '#if' ){
-			$self->if_sub();
-		} elsif( $tag eq '#foreach' ){
-			$self->foreach_sub();
+		#( $htm, $tag, $self->{contents} ) = split( /(#if|#foreach)/is, $self->{contents}, 2 );
+		@s = split( /(#if|#foreach)/is, $self->{contents}, 2 );
+		if( scalar( @s ) >= 3 ){
+			$self->{contents} = $s[2];
+		} else {
+			$self->{contents} = '';
+		}
+		if( scalar( @s ) >= 2 ){
+			$tag = $s[1];
+		#if( defined $tag ){
+			if( $tag eq '#if' ){
+				$self->if_sub();
+			} elsif( $tag eq '#foreach' ){
+				$self->foreach_sub();
+			}
+		}
+		if( scalar( @s ) >= 1 ){
+			$htm = $s[0];
+		#if( defined $htm ){
+			$contents .= $htm;
 		}
-		$contents .= $htm;
 	}
 
 	$contents;
 }
 
+=head2 if_sub
+
+    private function.
+
+=cut
 #======================================================================
 sub if_sub {
 	my $self = shift;
@@ -138,6 +229,11 @@ sub if_sub {
 	$self->{contents} = $contents. $self->{contents};
 }
 
+=head2 foreach_sub
+
+    private function.
+
+=cut
 #======================================================================
 sub foreach_sub {
 	my $self = shift;
@@ -189,6 +285,11 @@ sub foreach_sub {
 	$self->{contents} = $contents. $self->{contents};
 }
 
+=head2 get_end
+
+    private function.
+
+=cut
 #======================================================================
 sub get_end {
 	my $self = shift;
@@ -227,6 +328,11 @@ sub get_end {
 	}
 }
 
+=head2 marge_val
+
+    private function.
+
+=cut
 #======================================================================
 sub marge_val {
 	my $self = shift;
@@ -244,6 +350,11 @@ sub marge_val {
 	$retstr;
 }
 
+=head2 dump
+
+   Dump parameters.
+
+=cut
 #======================================================================
 sub dump {
 	my $self = shift;
@@ -253,198 +364,61 @@ sub dump {
 	print "templatefile=". $self->{templateFile}. "\n";
 }
 
-1; # Magic true value required at end of module
-__END__
 
-=head1 NAME
+=head1 AUTHOR
 
-TRD::Velocity - Template engine
+Takuya Ichikawa, C<< <trd.ichi at gmail.com> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-trd-velocity at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=TRD-Velocity>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
 
 
-=head1 VERSION
-
-This document describes TRD::Velocity version 0.0.4
 
 
-=head1 SYNOPSIS
+=head1 SUPPORT
 
-    use TRD::Velocity;
+You can find documentation for this module with the perldoc command.
 
-	$velo = new TRD::Velocity;
-	$velo->setTemplateFile( 'foo.html' );
-	$velo->set( 'name', 'value' );
-	$html_stmt = $velo->marge();
-	$ct = length( $html_stmt );
-	print "Content-Type: text/html\n";
-	print "Content-Length: ${ct}\n";
-	print "\n";
-	print $html_stmt;
-
-=for author to fill in:
-    Brief code example(s) here showing commonest usage(s).
-    This section will be as far as many users bother reading
-    so make it as educational and exeplary as possible.
-  
-  
-=head1 DESCRIPTION
-
-	This module is replace Template on TemplateString.
-	
-=for author to fill in:
-    Write a full description of the module and its features here.
-    Use subsections (=head2, =head3) as appropriate.
+    perldoc TRD::Velocity
 
 
-=head1 INTERFACE 
+You can also look for information at:
 
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
+=over 4
 
+=item * RT: CPAN's request tracker
 
-=head1 DIAGNOSTICS
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=TRD-Velocity>
 
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
+=item * AnnoCPAN: Annotated CPAN documentation
 
-=over
+L<http://annocpan.org/dist/TRD-Velocity>
 
-=item new
-new Constructor of people.
+=item * CPAN Ratings
 
-=item set
-set parameter.
+L<http://cpanratings.perl.org/d/TRD-Velocity>
 
-=item setTemplateFile
-set Template file.
+=item * Search CPAN
 
-=item setTemplateData
-set Template data.
-
-=item marge
-marge Template to parameters.
-
-=item dump
-dump parameters.
-
-=item tag_handler
-tag handler
-
-=item if_sub
-tag '#if' subroutine.
-
-=item foreach_sub
-tag '#foreach' subroutine.
-
-=item get_end
-get to tag '#end'
-
-=item marge_val
-store parameter.
-
-=item C<< Error message here, perhaps with %s placeholders >>
-
-[Description of error here]
-
-=item C<< Another error message here >>
-
-[Description of error here]
-
-[Et cetera, et cetera]
+L<http://search.cpan.org/dist/TRD-Velocity>
 
 =back
 
 
-=head1 CONFIGURATION AND ENVIRONMENT
-
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-  
-TRD::Velocity requires no configuration files or environment variables.
+=head1 ACKNOWLEDGEMENTS
 
 
-=head1 DEPENDENCIES
+=head1 COPYRIGHT & LICENSE
 
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
+Copyright 2008 Takuya Ichikawa, all rights reserved.
 
-None.
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 
-=head1 INCOMPATIBILITIES
+=cut
 
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
-None reported.
-
-
-=head1 BUGS AND LIMITATIONS
-
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
-No bugs have been reported.
-
-Please report any bugs or feature requests to
-C<bug-trd-velocity@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
-
-=head1 AUTHOR
-
-Takuya Ichikawa  C<< <trd.ichi@gmail.com> >>
-
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright (c) 2008, Takuya Ichikawa C<< <trd.ichi@gmail.com> >>. All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
-
-
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+1; # End of TRD::Velocity
